config

package
v1.7.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2025 License: GPL-3.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Default = Config{}

Functions

func GetDefaultPath added in v1.7.0

func GetDefaultPath() (string, error)

GetDefaultPath will return the default path for the config file

Types

type Config

type Config struct {
	Keymap map[string]KeymapConfig `yaml:"keymap"`
	// contains filtered or unexported fields
}

func New

func New(path string) (*Config, error)

New will create a new config structure

func (*Config) Load added in v1.7.0

func (cfg *Config) Load() error

Load will try to load the config structure from a file

type KeyList added in v1.7.0

type KeyList []string

type KeymapConfig added in v1.7.0

type KeymapConfig map[string]KeyList

Jump to